@@ -5,10 +5,9 @@ use strict;
 
 # XXX: check if we have rake command installed.
 sub run {
-    my $self = shift;
-    my $path = shift;
+    my ($self,$pkgfile,$path)=@_;
     if ( -e "rakefile" or -e 'rakefile' ) {
-        $logger->info( "Rakefile found. do rake install.") ;
+        print "Rakefile found. do rake install.\n";
         my $ret = system( "rake install" );
         return 1 if $ret == 0;
     }
